geowatch.cli.queue\_cli.prepare\_cold\_transfer module
======================================================

.. automodule:: geowatch.cli.queue_cli.prepare_cold_transfer
   :members:
   :undoc-members:
   :show-inheritance:
